#!/usr/bin/env bash


cat <<EOF 

To refresh the autogenerated files you need to install the cddlib
spkg, rerun autotools, and then copy the newly generated files into
the patches/autogenerated directory. This script helps with the last
part, namely copying the relevant autogenerated files.

This script must be run inside the patches/ directory and requires a
single argument, the spkg build directory from where the newly
generated files are copied.

In short, you need to do the following. First, install the spkg:

  [user@localhost]$ sage -pkg cddlib-<version>
  [user@localhost]$ sage -i -s cddlib-<version>.spkg
  ... does not matter if it actually compiles ...

Then, rerun the autotools:

  [user@localhost]$ cd $SAGE_LOCAL/spkg/build/cddlib-<version>/src
  [user@localhost]$ autoreconf -fiv

Finally, copy the newly generated files:

  [user@localhost]$ cd cddlib-<version>/patches/
  [user@localhost]$ ./refresh_autogenerated.sh $SAGE_LOCAL/spkg/build/cddlib-<version>/src
EOF
echo 

PATCHDIR=`pwd`
BUILDDIR=$1


echo "Copying autogenerated files from $BUILDDIR to $PATCHDIR"
[ ! -d "$BUILDDIR" ] && echo "Directory does not exist" && exit 1
[ ! -d "$PATCHDIR/autogenerated" ] && echo "You are not in the patches/ directory" && exit 1

cd $PATCHDIR/autogenerated
for i in `find . -type f` ; do cp -Rp $BUILDDIR/$i $i ; done


